/* MCVE v3.x C API
   (c) 2002 by Main Street Softworks, Inc.
   Written by Brad House

   This API is being released to the public domain to be modified and used in any manor the holder of this code sees fit.
   For any questions please contact  support@mainstreetsoftworks.com
*/
#include "libmonetra_main.h"
#include <sys/stat.h>
#ifdef _WIN32
#  define unlink(a) _unlink(a)
#endif

#ifdef M_DROPFILE_ENABLED
long M_FileSize (FILE * fp)
{
	long pos, len;
	pos = ftell (fp);
	fseek (fp, 0L, SEEK_END);
	len = ftell (fp);
	fseek (fp, pos, SEEK_SET);
	return (len);
}

int M_Monitor_File (M_CONN * myconn)
{
	_M_CONN *conn = (_M_CONN *) (*myconn);
	char filename[255];
	struct stat st;
	char *transaction = NULL;
	long flen;
	M_QUEUE *ptr = NULL;
	FILE *fp;

	ptr = conn->queue;
	while (ptr != NULL) {
		if (ptr->status == M_PENDING) {
			M_snprintf(filename, sizeof(filename), "%s/%s.rtn", conn->location, ptr->identifier);
			M_FixPath_inplace(filename);
			/* File found */
			if (stat (filename, &st) == 0) {
				/* Make sure the file got a chance to be
				 * written */
				M_uwait (500000);
				fp = fopen (filename, "rb");
				if (fp == NULL) {
					/* can't open that file ... yet
					   anyhow */
					continue;
				}
				flen = M_FileSize (fp);
				if (flen < 3) {
					/* File is too small to be valid ...
					 * will probably actually be zero */
					fclose (fp);
					continue;
				}
				transaction = (char *) malloc (flen + 2);
				memset (transaction, 0, flen + 1);
				fread (transaction, flen, sizeof (char), fp);	/* Read 
										   the 
										   contents 
										   to 
										   a 
										   buffer */
				fclose (fp);
				M_lock(myconn);
				/* M_ProcessResponse does not acquire locks */
				M_ProcessResponse (myconn, ptr->identifier,
						   transaction);
				M_unlock(myconn);
				free (transaction);
				unlink (filename);	/* Delete the file so 
							   it won't read it
							   again */
			}
		}
		ptr = ptr->next;
		if (ptr == conn->queue)
			break;
	}
	return (1);
}

int M_SendTransaction_File (M_CONN * myconn, char *identifier,
			    char *transaction)
{
	_M_CONN *conn = (_M_CONN *) (*myconn);
	char filename[300];
	FILE *fp;
	M_snprintf(filename, sizeof(filename), "%s/%s.trn", conn->location, identifier);
	M_FixPath_inplace(filename);
	fp = fopen (filename, "wb");
	if (fp == NULL) {
		return (0);
	}
	fwrite (transaction, strlen (transaction), 1, fp);
	fclose (fp);
	return (1);
}

#endif
