#!/bin/sh

die() {
	echo "$*"
	exit 1
}

if [ "$#" != "2" ] ; then
	die "please specify version and arch, ex  7.0.0 x86"
fi
VERSION=$1
VERSION_MAJOR=`echo $VERSION | cut -d . -f 1`
VERSION_MINOR=`echo $VERSION | cut -d . -f 2`
VERSION_RELEASE=`echo $VERSION | cut -d . -f 3`
ARCH=$2

if [ "${ARCH}" != "x86" -a "${ARCH}" != "x64" ] ; then
	die "arch must be x86 or x64"
fi

mydir="libmonetra-win-${ARCH}-$1"
zipfile="$mydir.zip"

if [ -d "$mydir" ] ; then
	rm -rf $mydir || die "unable to clean previous dir"
fi

mkdir $mydir || die "unable to create dir"
mkdir $mydir/include || die "unable to create include dir"
mkdir $mydir/examples || die "unable to create examples dir"
mkdir $mydir/examples/csharp || die "unable to create csharp dir"
mkdir $mydir/examples/csharp/Properties || die "unable to create properties dir"
mkdir $mydir/examples/vb6 || die "unable to create vb6 dir"
mkdir $mydir/examples/vbnet || die "unable to create vbnet dir"
mkdir "$mydir/examples/vbnet/libmonetra" || die "unable to create vbnet project dir"
mkdir $mydir/examples/c || die "unable to create c dir"

headers_list="monetra.h libmonetra_legacy.h libmonetra_compat.h libmonetra_defines.h libmonetra_w32config.h"

for x in $headers_list ; do 
	cp $x $mydir/include || die "unable to copy includes : $x"
done

if [ "${ARCH}" = "x86" ] ; then
cp win32/libmonetra/Release/libmonetra.dll $mydir || die "unable to copy libmonetra.dll"
cp win32/libmonetra/Release/libmonetra.lib $mydir || die "unable to copy libmonetra.lib"
cp win32/libmonetra_stdcall/Release/libmonetra_stdcall.dll $mydir || die "unable to copy libmonetra_stdcall.dll"
cp win32/libmonetra_stdcall/Release/libmonetra_stdcall.lib $mydir || die "unable to copy libmonetra_stdcall.lib"
cp win32/w32test/Release/w32test.exe $mydir || die "unable to copy w32test.exe" 
else
cp win32/libmonetra/x64/Release/libmonetra.dll $mydir || die "unable to copy libmonetra.dll"
cp win32/libmonetra/x64/Release/libmonetra.lib $mydir || die "unable to copy libmonetra.lib"
cp win32/libmonetra_stdcall/x64/Release/libmonetra_stdcall.dll $mydir || die "unable to copy libmonetra_stdcall.dll"
cp win32/libmonetra_stdcall/x64/Release/libmonetra_stdcall.lib $mydir || die "unable to copy libmonetra_stdcall.lib"
cp win32/w32test/x64/Release/w32test.exe $mydir || die "unable to copy w32test.exe" 
fi

cp win32/libmonetra_csharp/bin/Release/libmonetra_csharp.exe $mydir || die "unable to copy libmonetra_csharp.exe"
cp win32/libmonetra_vbnet/bin/Release/libmonetra_vbnet.exe $mydir || die "unable to copy libmonetra_vbnet.exe"

cp win32/libmonetra_csharp/Program.cs $mydir/examples/csharp || die "Program.cs"
cp win32/libmonetra_csharp/libmonetra_csharp.csproj $mydir/examples/csharp || die "csproj" 
cp win32/libmonetra_csharp/Properties/AssemblyInfo.cs $mydir/examples/csharp/Properties || die "Properties/AssemblyInfo" 

cp win32/w32test/w32test.c $mydir/examples/c || die "w32test.c"

cp win32/libmonetra_vbnet/Module1.vb $mydir/examples/vbnet || die "Module1.vb"
cp win32/libmonetra_vbnet/libmonetra_vbnet.vbproj $mydir/examples/vbnet || die ".vbproj"
cp win32/libmonetra_vbnet/libmonetra/* $mydir/examples/vbnet/libmonetra/ || die "vbnet project info"

cp win32/libmonetra_vb6/libmonetra_vb6.bas $mydir/examples/vb6/ || die "vb6"

# Must be copied to base directory since package.dll depends on them!
if [ "${ARCH}" = "x86" ] ; then
	cp /cygdrive/c/Program\ Files\ \(x86\)/Microsoft\ Visual\ Studio\ 8/VC/redist/x86/Microsoft.VC80.CRT/* $mydir/ || die "unable to copy c runtime library"
	cp "/cygdrive/c/Program Files/OpenSSL/lib/libmssl.dll" $mydir || die "unable to copy libmssl.dll"
	cp "/cygdrive/c/Program Files/OpenSSL/lib/libmcrypto.dll" $mydir || die "unable to copy libmcrypto"
	cp "/cygdrive/c/Program Files/OpenSSL/lib/libmssl.dll.manifest" $mydir || die "unable to copy libmssl.dll.manifest"
	cp "/cygdrive/c/Program Files/OpenSSL/lib/libmcrypto.dll.manifest" $mydir || die "unable to copy libmcrypto.dll.manifest"
else
	cp /cygdrive/c/Program\ Files\ \(x86\)/Microsoft\ Visual\ Studio\ 8/VC/redist/amd64/Microsoft.VC80.CRT/* $mydir/ || die "unable to copy c runtime library"
	cp "/cygdrive/c/Program Files/OpenSSL64/lib/libmssl.dll" $mydir || die "unable to copy libmssl.dll"
	cp "/cygdrive/c/Program Files/OpenSSL64/lib/libmcrypto.dll" $mydir || die "unable to copy libmcrypto"
	cp "/cygdrive/c/Program Files/OpenSSL64/lib/libmssl.dll.manifest" $mydir || die "unable to copy libmssl.dll.manifest"
	cp "/cygdrive/c/Program Files/OpenSSL64/lib/libmcrypto.dll.manifest" $mydir || die "unable to copy libmcrypto.dll.manifest"
fi



zip -r $zipfile $mydir || die "creating zip file failed"
rm -rf $mydir

echo "done"
exit 0

