#!/bin/bash

PKGNAME="libmonetra"
SSL_DIR="/usr"

TMPDIR=""

die() {
	echo "$*"
	if [ "$TMPDIR" != "" ] ; then
		rm -rf "$TMPDIR"
	fi
	exit 1
}

if [ "$#" != "1" ] ; then
	die "Usage: $0 version"
fi

VERSION="$1"
TMPDIR=`mktemp -d`
CURDIR=`pwd`

if [ "$TMPDIR" = "" ] ; then
	die "mktemp failed"
fi

WORKINGDIR="$TMPDIR/$PKGNAME-$VERSION"

mkdir -p "$WORKINGDIR" || die "mkdir failed"

cp -Rpv . "$WORKINGDIR/" || die "failed to copy files"

cd "$WORKINGDIR" || die "failed to change to working dir ($WORKINGDIR)"

while read x ; do
	echo "Removing SVN dir $x..."
	rm -rf "$x" || die "failed to remove $x"
done <<< "`find . | grep '.svn$'`"

./buildconf.sh || die "buildconf failed"
./configure --with-ssl="$SSL_DIR" || die "configure failed"
make clean || die "make clean failed"
make || die "make failed"
make distclean || die "make distclean failed"

rm -rf autom4te.cache *.log *.gz *~

cd .. || die "failed to go down a dir"

echo "Creating ../$PKGNAME-$VERSION.tar.gz ..."
tar -zcvpf "$CURDIR/../$PKGNAME-$VERSION.tar.gz" $PKGNAME-$VERSION || die "tar failed"

cd $CURDIR

rm -rf "$TMPDIR"
echo "done"
